@@ -1,6 +1,6 @@
 use MooseX::Declare;
 
-class TSQL::AST::TryCatchBlock Extends TSQL::AST::SQLStatement {
+class TSQL::AST::TryCatchBlock extends TSQL::AST::SQLStatement {
 
 has 'tryBlock' => (
       is  => 'rw',
